# Copyright © 2021-2022 Arrikto Inc.  All Rights Reserved.

"""Kale SDK.

This script creates an ML pipeline to split a dataset.
"""

import json

from sklearn.datasets import load_digits

from kale import ContainerStep
from kale.sdk import step, pipeline


@step(name="load_data")
def load_dataset():
    """Load the Digits dataset."""
    x, y = load_digits(return_X_y=True)
    filename_x = "/kale_marshal_dir/x.txt"
    filename_y = "/kale_marshal_dir/y.txt"

    with open(filename_x, "w") as f:
        json.dump(x.tolist(), f)
    with open(filename_y, "w") as f:
        json.dump(y.tolist(), f)

    return filename_x, filename_y


split_dataset = ContainerStep(
    name="split_dataset",
    image="gcr.io/arrikto/example-add-split",
    command=["python", "/split.py"],
    args=["{{input.x}}", "{{input.y}}",
          "{{outfile.x_test}}", "{{outfile.y_test}}"],
    volume_mounts=["/kale_marshal_dir"])


@step(name="print_data")
def print_dataset(x, y):
    """Print a slice of the Digits dataset."""
    with open(x, "r") as f:
        x_test = json.load(f)

    with open(y, "r") as f:
        y_test = json.load(f)
    print("The 1st digit is:", y_test[0])
    print("The 1st image array is:", x_test[0])


@pipeline(name="split-dataset",
          experiment="kale-tutorial",
          marshal_volume=True,
          marshal_path="/kale_marshal_dir")
def pipeline_func():
    """Run the ML pipeline."""
    x, y = load_dataset()
    x_new, y_new = split_dataset(x, y)
    print_dataset(x=x_new, y=y_new)


if __name__ == "__main__":
    pipeline_func()
